@@ -2,7 +2,7 @@
  * deprecated.h:  libvlc deprecated API
  *****************************************************************************
  * Copyright (C) 1998-2008 the VideoLAN team
- * $Id: ba9a7be9ded108066ada4cc5bff1b52882119ad1 $
+ * $Id: 2cb82e11034c42b79115efd043f41fdfd06aa1eb $
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Jean-Paul Saman <jpsaman@videolan.org>
@@ -30,21 +30,59 @@
  * This file defines libvlc depreceated API
  */
 
+/**
+ * This is the legacy representation of a platform-specific drawable. Because
+ * it cannot accomodate a pointer on most 64-bits platforms, it should not be
+ * used anymore.
+ */
+typedef int libvlc_drawable_t;
+
 # ifdef __cplusplus
 extern "C" {
 # endif
 
+/**
+ * Set the drawable where the media player should render its video output.
+ *
+ * On Windows 32-bits, a window handle (HWND) is expected.
+ * On Windows 64-bits, this function will always fail.
+ *
+ * On OSX 32-bits, a CGrafPort is expected.
+ * On OSX 64-bits, this function will always fail.
+ *
+ * On other platforms, an existing X11 window ID is expected. See
+ * libvlc_media_player_set_xid() for details.
+ *
+ * \param p_mi the Media Player
+ * \param drawable the libvlc_drawable_t where the media player
+ *        should render its video
+ * \param p_e an initialized exception pointer
+ */
+VLC_DEPRECATED_API void libvlc_media_player_set_drawable ( libvlc_media_player_t *, libvlc_drawable_t, libvlc_exception_t * );
+
+/**
+ * Get the drawable where the media player should render its video output
+ *
+ * \param p_mi the Media Player
+ * \param p_e an initialized exception pointer
+ * \return the libvlc_drawable_t where the media player
+ *         should render its video
+ */
+VLC_DEPRECATED_API libvlc_drawable_t
+                    libvlc_media_player_get_drawable ( libvlc_media_player_t *, libvlc_exception_t * );
+
 /**
  * Set the default video output's parent.
  *
- * This setting will be used as default for all video outputs.
+ * This setting will be used as default for any video output.
  *
  * \param p_instance libvlc instance
- * \param drawable the new parent window (Drawable on X11, CGrafPort on MacOSX, HWND on Win32)
+ * \param drawable the new parent window
+ *                 (see libvlc_media_player_set_drawable() for details)
  * \param p_e an initialized exception pointer
  * @deprecated Use libvlc_media_player_set_drawable
  */
-VLC_PUBLIC_API void libvlc_video_set_parent( libvlc_instance_t *, libvlc_drawable_t, libvlc_exception_t * );
+VLC_DEPRECATED_API void libvlc_video_set_parent( libvlc_instance_t *, libvlc_drawable_t, libvlc_exception_t * );
 
 /**
  * Set the default video output parent.
@@ -56,7 +94,59 @@ VLC_PUBLIC_API void libvlc_video_set_parent( libvlc_instance_t *, libvlc_drawabl
  * \param p_e an initialized exception pointer
  * @deprecated Use libvlc_media_player_get_drawable
  */
-VLC_PUBLIC_API libvlc_drawable_t libvlc_video_get_parent( libvlc_instance_t *, libvlc_exception_t * );
+VLC_DEPRECATED_API libvlc_drawable_t libvlc_video_get_parent( libvlc_instance_t *, libvlc_exception_t * );
+
+/**
+ * Does nothing. Do not use this function.
+ */
+VLC_DEPRECATED_API int libvlc_video_reparent( libvlc_media_player_t *, libvlc_drawable_t, libvlc_exception_t * );
+
+/**
+ * Resize the current video output window.
+ * This might crash. Please use libvlc_video_set_scale() instead.
+ *
+ * \param p_mi media player instance
+ * \param width new width for video output window
+ * \param height new height for video output window
+ * \param p_e an initialized exception pointer
+ * \return the success status (boolean)
+ */
+VLC_DEPRECATED_API void libvlc_video_resize( libvlc_media_player_t *, int, int, libvlc_exception_t *);
+
+/**
+ * Tell windowless video output to redraw rectangular area (MacOS X only).
+ * This might crash. Do not use this function.
+ *
+ * \param p_mi media player instance
+ * \param area coordinates within video drawable
+ * \param p_e an initialized exception pointer
+ */
+VLC_DEPRECATED_API void libvlc_video_redraw_rectangle( libvlc_media_player_t *, const libvlc_rectangle_t *, libvlc_exception_t * );
+
+/**
+ * Set the default video output size.
+ * This setting will be used as default for all video outputs.
+ *
+ * \param p_instance libvlc instance
+ * \param width new width for video drawable
+ * \param height new height for video drawable
+ * \param p_e an initialized exception pointer
+ */
+VLC_DEPRECATED_API void libvlc_video_set_size( libvlc_instance_t *, int, int, libvlc_exception_t * );
+
+/**
+ * Set the default video output viewport for a windowless video output
+ * (MacOS X only). This might crash. Do not use this function.
+ *
+ * This setting will be used as default for all video outputs.
+ *
+ * \param p_instance libvlc instance
+ * \param p_mi media player instance
+ * \param view coordinates within video drawable
+ * \param clip coordinates within video drawable
+ * \param p_e an initialized exception pointer
+ */
+VLC_DEPRECATED_API void libvlc_video_set_viewport( libvlc_instance_t *, libvlc_media_player_t *, const libvlc_rectangle_t *, const libvlc_rectangle_t *, libvlc_exception_t * );
 
 /*
  * This function shall not be used at all. It may lead to crash and race condition.
@@ -125,6 +215,8 @@ VLC_DEPRECATED_API int libvlc_playlist_isplaying( libvlc_instance_t *,
 /**
  * Get the number of items in the playlist
  *
+ * Expects the playlist instance to be locked already.
+ *
  * \param p_instance the playlist instance
  * \param p_e an initialized exception pointer
  * \return the number of items
