@@ -2,7 +2,7 @@
  * common.h : DirectShow access module for vlc
  *****************************************************************************
  * Copyright (C) 2002 the VideoLAN team
- * $Id: common.h 13909 2006-01-14 09:36:16Z jpsaman $
+ * $Id: 6a3f2b5ea22a3c1fb09f567f767a658782e88026 $
  *
  * Author: Gildas Bazin <gbazin@videolan.org>
  *
@@ -34,11 +34,16 @@ using namespace std;
 #   include <unknwn.h>
 #   include <ole2.h>
 #   include <limits.h>
+#   ifdef _WINGDI_
+#      undef _WINGDI_
+#   endif
 #   define _WINGDI_ 1
 #   define AM_NOVTABLE
 #   define _OBJBASE_H_
 #   undef _X86_
-#   define _I64_MAX LONG_LONG_MAX
+#   ifndef _I64_MAX
+#     define _I64_MAX LONG_LONG_MAX
+#   endif
 #   define LONGLONG long long
 #endif
 
@@ -90,5 +95,5 @@ struct access_sys_t
     int            i_width;
     int            i_height;
     int            i_chroma;
-    vlc_bool_t     b_chroma; /* Force a specific chroma on the dshow input */
+    bool           b_chroma; /* Force a specific chroma on the dshow input */
 };
