@@ -2,7 +2,7 @@
  * subsdec.c : text subtitles decoder
  *****************************************************************************
  * Copyright (C) 2000-2006 the VideoLAN team
- * $Id: 0830dbf20de452911a7d8bc8d5623ac489abc70b $
+ * $Id: 6a3612f1d3ec233e382b2b80f19d2336e8b79636 $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *          Samuel Hocevar <sam@zoy.org>
@@ -68,7 +68,7 @@ static const char *const ppsz_encodings[] = {
     "ISO-8859-6",
     "Windows-1256",
     "ISO-8859-7",
-    "Windows-1256",
+    "Windows-1253",
     "ISO-8859-8",
     "Windows-1255",
     "ISO-8859-9",
@@ -121,7 +121,7 @@ static const char *const ppsz_encoding_names[] = {
     N_("Arabic (Windows-1256)"),
     /* 7 */
     N_("Greek (ISO 8859-7)"),
-    N_("Greek (Windows-1256)"),
+    N_("Greek (Windows-1253)"),
     /* 8 */
     N_("Hebrew (ISO 8859-8)"),
     N_("Hebrew (Windows-1255)"),
@@ -940,6 +940,31 @@ static char *CreateHtmlSubtitle( int *pi_align, char *psz_subtitle )
             /* Hide {\stupidity} */
             psz_subtitle = strchr( psz_subtitle, '}' ) + 1;
         }
+        else if( psz_subtitle[0] == '{' && psz_subtitle[1] == 'Y'
+                && psz_subtitle[2] == ':' && strchr( psz_subtitle, '}' ) )
+        {
+            /* Hide {Y:stupidity} */
+            psz_subtitle = strchr( psz_subtitle, '}' ) + 1;
+        }
+        else if( psz_subtitle[0] == '\\' && psz_subtitle[1] )
+        {
+            if( psz_subtitle[1] == 'N' || psz_subtitle[1] == 'n' )
+            {
+                HtmlPut( &psz_html, "<br/>" );
+                psz_subtitle += 2;
+            }
+            else if( psz_subtitle[1] == 'h' )
+            {
+                /* Non breakable space */
+                HtmlPut( &psz_html, NO_BREAKING_SPACE );
+                psz_subtitle += 2;
+            }
+            else
+            {
+                HtmlPut( &psz_html, "\\" );
+                psz_subtitle++;
+            }
+        }
         else
         {
             *psz_html = *psz_subtitle;
