@@ -2,7 +2,7 @@
  * asf.c : ASF demux module
  *****************************************************************************
  * Copyright (C) 2002-2003 the VideoLAN team
- * $Id: 08296a6a2970203e1c3f78d892ac909b11dbd403 $
+ * $Id: 1f63bbd9e2b4d1d562ae4202d78d21f3193e39da $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -360,7 +360,6 @@ static mtime_t GetMoviePTS( demux_sys_t *p_sys )
         {
             if( i_time < 0 ) i_time = tk->i_time;
             else i_time = __MIN( i_time, tk->i_time );
-            break;
         }
     }
 
@@ -595,8 +594,10 @@ static int DemuxPacket( demux_t *p_demux )
                 /* send complete packet to decoder */
                 block_t *p_gather = block_ChainGather( tk->p_frame );
 
+                tk->i_time = p_gather->i_dts;
+
                 if( p_sys->i_time < 0 )
-                    es_out_Control( p_demux->out, ES_OUT_SET_PCR, tk->i_time );
+                    es_out_Control( p_demux->out, ES_OUT_SET_PCR, tk->i_time+1 );
 
                 es_out_Send( p_demux->out, tk->p_es, p_gather );
 
@@ -616,11 +617,7 @@ static int DemuxPacket( demux_t *p_demux )
 
             if( tk->p_frame == NULL )
             {
-                tk->i_time =
-                    ( (mtime_t)i_pts + i_payload * (mtime_t)i_pts_delta );
-
-                p_frag->i_pts = tk->i_time;
-
+                p_frag->i_pts = i_pts + i_payload * (mtime_t)i_pts_delta;
                 if( tk->i_cat != VIDEO_ES )
                     p_frag->i_dts = p_frag->i_pts;
                 else
