@@ -1,8 +1,8 @@
 /*****************************************************************************
 * simple_prefs.h: Simple Preferences for Mac OS X
 *****************************************************************************
-* Copyright (C) 2008 the VideoLAN team
-* $Id$
+* Copyright (C) 2008-2009 the VideoLAN team
+* $Id: 936a4cf158f4f872ca4146d8e585b283a5f4bdb0 $
 *
 * Authors: Felix Paul Kühne <fkuehne at videolan dot org>
 *
@@ -89,6 +89,9 @@
     IBOutlet id o_intf_art_txt;
     IBOutlet id o_intf_embedded_ckb;
     IBOutlet id o_intf_fspanel_ckb;
+	IBOutlet id o_intf_appleremote_ckb;
+	IBOutlet id o_intf_mediakeys_ckb;
+    IBOutlet id o_intf_mediakeys_bg_ckb;
     IBOutlet id o_intf_lang_pop;
     IBOutlet id o_intf_lang_txt;
     IBOutlet id o_intf_network_box;
