@@ -2,7 +2,7 @@
  * pda.c : PDA Gtk2 plugin for vlc
  *****************************************************************************
  * Copyright (C) 2002 the VideoLAN team
- * $Id: 15719707632955b6c90b5457560578033c0bd00c $
+ * $Id: 2b74125970b4cfd0019d2b28bc1e1fe33a3f4d61 $
  *
  * Authors: Jean-Paul Saman <jpsaman  _at_ videolan _dot_ org>
  *          Marc Ariberti <marcari@videolan.org>
@@ -51,7 +51,6 @@ static int  Open         ( vlc_object_t * );
 static void Close        ( vlc_object_t * );
 static void Run          ( intf_thread_t * );
 
-void GtkAutoPlayFile     ( vlc_object_t * );
 static int Manage        ( intf_thread_t *p_intf );
 void GtkDisplayDate  ( GtkAdjustment *p_adj, gpointer userdata );
 gint GtkModeManage   ( intf_thread_t * p_intf );
@@ -66,15 +65,14 @@ gint GtkModeManage   ( intf_thread_t * p_intf );
 /*****************************************************************************
  * Module descriptor
  *****************************************************************************/
-vlc_module_begin();
-    set_description( N_("PDA Linux Gtk2+ interface") );
-    set_category( CAT_INTERFACE );
-    set_subcategory( SUBCAT_INTERFACE_MAIN );
-//    add_bool( "pda-autoplayfile", 1, GtkAutoPlayFile, AUTOPLAYFILE_TEXT, AUTOPLAYFILE_LONGTEXT, true );
-    set_capability( "interface", 0 );
-    set_callbacks( Open, Close );
-    add_shortcut( "pda" );
-vlc_module_end();
+vlc_module_begin ()
+    set_description( N_("PDA Linux Gtk2+ interface") )
+    set_category( CAT_INTERFACE )
+    set_subcategory( SUBCAT_INTERFACE_MAIN )
+    set_capability( "interface", 0 )
+    set_callbacks( Open, Close )
+    add_shortcut( "pda" )
+vlc_module_end ()
 
 /*****************************************************************************
  * Open: initialize and create window
@@ -86,15 +84,12 @@ static int Open( vlc_object_t *p_this )
     /* Allocate instance and initialize some members */
     p_intf->p_sys = malloc( sizeof( intf_sys_t ) );
     if( p_intf->p_sys == NULL )
-    {
-        msg_Err( p_intf, "out of memory" );
         return VLC_ENOMEM;
-    }
 
 #ifdef NEED_GTK2_MAIN
     msg_Dbg( p_intf, "Using gui-helper" );
     p_intf->p_sys->p_gtk_main =
-        module_Need( p_this, "gui-helper", "gtk2", true );
+        module_need( p_this, "gui-helper", "gtk2", true );
     if( p_intf->p_sys->p_gtk_main == NULL )
     {
         free( p_intf->p_sys );
@@ -128,7 +123,7 @@ static void Close( vlc_object_t *p_this )
 
 #ifdef NEED_GTK2_MAIN
     msg_Dbg( p_intf, "Releasing gui-helper" );
-    module_Unneed( p_intf, p_intf->p_sys->p_gtk_main );
+    module_unneed( p_intf, p_intf->p_sys->p_gtk_main );
 #endif
 
     /* Destroy structure */
@@ -156,6 +151,7 @@ static void Run( intf_thread_t *p_intf )
     GtkTreeViewColumn *p_column   = NULL;
     GtkListStore      *p_filelist = NULL;
     GtkListStore      *p_playlist_store = NULL;
+    int canc = vlc_savecancel();
 
 #ifndef NEED_GTK2_MAIN
     gtk_set_locale ();
@@ -288,7 +284,7 @@ static void Run( intf_thread_t *p_intf )
     gtk_tree_view_column_set_sort_column_id(p_column, 2);
 #endif
     /* update the playlist */
-    p_playlist = pl_Yield( p_intf );
+    p_playlist = pl_Hold( p_intf );
     p_playlist_store = gtk_list_store_new (3,
                 G_TYPE_STRING, /* Filename */
                 G_TYPE_STRING, /* Time */
@@ -316,7 +312,7 @@ static void Run( intf_thread_t *p_intf )
 
 #ifdef NEED_GTK2_MAIN
     msg_Dbg( p_intf, "Manage GTK keyboard events using threads" );
-    while( !intf_ShouldDie( p_intf ) )
+    while( vlc_object_alive( p_intf ) )
     {
         Manage( p_intf );
 
@@ -348,43 +344,7 @@ static void Run( intf_thread_t *p_intf )
 #ifdef NEED_GTK2_MAIN
     gdk_threads_leave();
 #endif
-}
-
-/*****************************************************************************
- * GtkAutoplayFile: Autoplay file depending on configuration settings
- *****************************************************************************/
-void GtkAutoPlayFile( vlc_object_t *p_this )
-{
-    GtkWidget *cbautoplay;
-    intf_thread_t *p_intf;
-    int i_index;
-    vlc_list_t *p_list = vlc_list_find( p_this, VLC_OBJECT_INTF,
-                                        FIND_ANYWHERE );
-
-    for( i_index = 0; i_index < p_list->i_count; i_index++ )
-    {
-        p_intf = (intf_thread_t *)p_list->p_values[i_index].p_object ;
-
-        if( strcmp( MODULE_STRING, module_GetObjName(p_intf->p_module) ) )
-        {
-            continue;
-        }
-        cbautoplay = GTK_WIDGET( gtk_object_get_data(
-                            GTK_OBJECT( p_intf->p_sys->p_window ),
-                            "cbautoplay" ) );
-
-        if( !config_GetInt( p_this, "pda-autoplayfile" ) )
-        {
-            p_intf->p_sys->b_autoplayfile = false;
-        }
-        else
-        {
-            p_intf->p_sys->b_autoplayfile = true;
-        }
-        gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( cbautoplay ),
-                                      p_intf->p_sys->b_autoplayfile );
-    }
-    vlc_list_release( p_list );
+    vlc_restorecancel(canc);
 }
 
 /* following functions are local */
@@ -398,7 +358,6 @@ void GtkAutoPlayFile( vlc_object_t *p_this )
 static int Manage( intf_thread_t *p_intf )
 {
     GtkListStore *p_liststore;
-    vlc_mutex_lock( &p_intf->change_lock );
 
     /* Update the input */
     if( p_intf->p_sys->p_input == NULL )
@@ -417,7 +376,6 @@ static int Manage( intf_thread_t *p_intf )
         input_thread_t *p_input = p_intf->p_sys->p_input;
         int64_t i_time = 0, i_length = 0;
 
-        vlc_object_lock( p_input );
         if( vlc_object_alive (p_input) )
         {
             playlist_t *p_playlist;
@@ -426,7 +384,7 @@ static int Manage( intf_thread_t *p_intf )
             p_intf->p_sys->b_playing = 1;
 
             /* update playlist interface */
-            p_playlist = pl_Yield( p_intf );
+            p_playlist = pl_Hold( p_intf );
             if (p_playlist != NULL)
             {
                 p_liststore = gtk_list_store_new (3,
@@ -468,9 +426,7 @@ static int Manage( intf_thread_t *p_intf )
                         double f_pos = (double)newvalue / 100.0;
 
                         /* release the lock to be able to seek */
-                        vlc_object_unlock( p_input );
                         var_SetFloat( p_input, "position", f_pos );
-                        vlc_object_lock( p_input );
 
                         /* Update the old value */
                         p_intf->p_sys->f_adj_oldvalue = newvalue;
@@ -502,9 +458,7 @@ static int Manage( intf_thread_t *p_intf )
                         double f_pos = (double)newvalue / 100.0;
 
                         /* release the lock to be able to seek */
-                        vlc_object_unlock( p_input );
                         var_SetFloat( p_input, "position", f_pos );
-                        vlc_object_lock( p_input );
 
                         /* Update the old value */
                         p_intf->p_sys->i_adj_oldvalue = newvalue;
@@ -512,19 +466,16 @@ static int Manage( intf_thread_t *p_intf )
                 }
             }
         }
-        vlc_object_unlock( p_input );
     }
-    else if( p_intf->p_sys->b_playing && !intf_ShouldDie( p_intf ) )
+    else if( p_intf->p_sys->b_playing && vlc_object_alive( p_intf ) )
     {
         GtkModeManage( p_intf );
         p_intf->p_sys->b_playing = 0;
     }
 
 #ifndef NEED_GTK2_MAIN
-    if( intf_ShouldDie( p_intf ) )
+    if( !vlc_object_alive( p_intf ) )
     {
-        vlc_mutex_unlock( &p_intf->change_lock );
-
         /* Prepare to die, young Skywalker */
         gtk_main_quit();
 
@@ -532,8 +483,6 @@ static int Manage( intf_thread_t *p_intf )
     }
 #endif
 
-    vlc_mutex_unlock( &p_intf->change_lock );
-
     return TRUE;
 }
 
@@ -597,7 +546,7 @@ gint GtkModeManage( intf_thread_t * p_intf )
         }
 
         /* control buttons for free pace streams */
-        b_control = p_intf->p_sys->p_input->b_can_pace_control;
+        b_control = var_GetBool( p_intf->p_sys->p_input, "can-rate" );
 
         msg_Dbg( p_intf, "stream has changed, refreshing interface" );
     }
