@@ -2,7 +2,7 @@
  * snapshot.c : snapshot plugin for vlc
  *****************************************************************************
  * Copyright (C) 2002 the VideoLAN team
- * $Id$
+ * $Id: 2fc7c2af8f89885436fb48481c887723fef1b57a $
  *
  * Authors: Olivier Aubert <oaubert@lisi.univ-lyon1.fr>
  *
@@ -26,10 +26,10 @@
  * keep a cache of low-res snapshots.
  * The snapshot structure is defined in include/snapshot.h
  * In order to access the current snapshot cache, object variables are used:
- *   snapshot-list-pointer : the pointer on the first element in the list
- *   snapshot-datasize     : size of a snapshot
+ *   vout-snapshot-list-pointer : the pointer on the first element in the list
+ *   vout-snapshot-datasize     : size of a snapshot
  *                           (also available in snapshot_t->i_datasize)
- *   snapshot-cache-size   : size of the cache list
+ *   vout-snapshot-cache-size   : size of the cache list
  *
  * It is used for the moment by the CORBA module and a specialized
  * python-vlc binding.
@@ -76,25 +76,37 @@ static void Display   ( vout_thread_t *, picture_t * );
 #define CACHE_LONGTEXT N_( "Snapshot cache size (number of images to keep)." )
 
 
-vlc_module_begin( );
-    set_description( N_( "Snapshot module" ) );
-    set_shortname( N_("Snapshot") );
+vlc_module_begin ()
+    set_description( N_( "Snapshot output" ) )
+    set_shortname( N_("Snapshot") )
 
-    set_category( CAT_VIDEO );
-    set_subcategory( SUBCAT_VIDEO_VOUT );
-    set_capability( "video output", 1 );
+    set_category( CAT_VIDEO )
+    set_subcategory( SUBCAT_VIDEO_VOUT )
+    set_capability( "video output", 1 )
 
-    add_integer( "snapshot-width", 320, NULL, WIDTH_TEXT, WIDTH_LONGTEXT, false );
-    add_integer( "snapshot-height", 200, NULL, HEIGHT_TEXT, HEIGHT_LONGTEXT, false );
-    add_string( "snapshot-chroma", "RV32", NULL, CHROMA_TEXT, CHROMA_LONGTEXT, true );
-    add_integer( "snapshot-cache-size", 50, NULL, CACHE_TEXT, CACHE_LONGTEXT, true );
+    add_integer( "vout-snapshot-width", 320, NULL, WIDTH_TEXT, WIDTH_LONGTEXT, false )
+    add_integer( "vout-snapshot-height", 200, NULL, HEIGHT_TEXT, HEIGHT_LONGTEXT, false )
+    add_string( "vout-snapshot-chroma", "RV32", NULL, CHROMA_TEXT, CHROMA_LONGTEXT, true )
+        add_deprecated_alias( "snapshot-chroma" )
+    add_integer( "vout-snapshot-cache-size", 50, NULL, CACHE_TEXT, CACHE_LONGTEXT, true )
+        add_deprecated_alias( "snapshot-cache-size" )
 
-    set_callbacks( Create, Destroy );
-vlc_module_end();
+    set_callbacks( Create, Destroy )
+vlc_module_end ()
 
 /*****************************************************************************
  * vout_sys_t: video output descriptor
  *****************************************************************************/
+typedef struct snapshot_t
+{
+  uint8_t *p_data;   /* Data area */
+
+  int i_width;       /* In pixels */
+  int i_height;      /* In pixels */
+  int i_datasize;    /* In bytes */
+  mtime_t date;      /* Presentation time */
+} snapshot_t;
+
 struct vout_sys_t
 {
     snapshot_t **p_list;    /* List of available snapshots */
@@ -118,11 +130,11 @@ static int Create( vlc_object_t *p_this )
     if( ! p_vout->p_sys )
         return VLC_ENOMEM;
 
-    var_Create( p_vout, "snapshot-width", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-height", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-datasize", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-cache-size", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-list-pointer", VLC_VAR_ADDRESS );
+    var_Create( p_vout, "vout-snapshot-width", VLC_VAR_INTEGER );
+    var_Create( p_vout, "vout-snapshot-height", VLC_VAR_INTEGER );
+    var_Create( p_vout, "vout-snapshot-datasize", VLC_VAR_INTEGER );
+    var_Create( p_vout, "vout-snapshot-cache-size", VLC_VAR_INTEGER );
+    var_Create( p_vout, "vout-snapshot-list-pointer", VLC_VAR_ADDRESS );
 
     p_vout->pf_init = Init;
     p_vout->pf_end = End;
@@ -147,15 +159,15 @@ static int Init( vout_thread_t *p_vout )
     int i_height;
     int i_datasize;
 
-    i_width  = config_GetInt( p_vout, "snapshot-width" );
-    i_height = config_GetInt( p_vout, "snapshot-height" );
+    i_width  = config_GetInt( p_vout, "vout-snapshot-width" );
+    i_height = config_GetInt( p_vout, "vout-snapshot-height" );
 
-    psz_chroma = config_GetPsz( p_vout, "snapshot-chroma" );
+    psz_chroma = config_GetPsz( p_vout, "vout-snapshot-chroma" );
     if( psz_chroma )
     {
         if( strlen( psz_chroma ) < 4 )
         {
-            msg_Err( p_vout, "snapshot-chroma should be 4 characters long" );
+            msg_Err( p_vout, "vout-snapshot-chroma should be 4 characters long" );
             return VLC_EGENERIC;
         }
         i_chroma = VLC_FOURCC( psz_chroma[0], psz_chroma[1],
@@ -248,11 +260,11 @@ static int Init( vout_thread_t *p_vout )
 
     p_vout->p_sys->i_datasize = i_datasize;
     p_vout->p_sys->i_index = 0;
-    p_vout->p_sys->i_size = config_GetInt( p_vout, "snapshot-cache-size" );
+    p_vout->p_sys->i_size = config_GetInt( p_vout, "vout-snapshot-cache-size" );
 
     if( p_vout->p_sys->i_size < 2 )
     {
-        msg_Err( p_vout, "snapshot-cache-size must be at least 1." );
+        msg_Err( p_vout, "vout-snapshot-cache-size must be at least 1." );
         return VLC_EGENERIC;
     }
 
@@ -273,24 +285,27 @@ static int Init( vout_thread_t *p_vout )
         p_snapshot->i_height = i_height;
         p_snapshot->i_datasize = i_datasize;
         p_snapshot->date = 0;
-        p_snapshot->p_data = ( char* ) malloc( i_datasize );
+        p_snapshot->p_data = malloc( i_datasize );
         if( p_snapshot->p_data == NULL )
+        {
+            free( p_snapshot );
             return VLC_ENOMEM;
+        }
         p_vout->p_sys->p_list[i_index] = p_snapshot;
     }
 
     val.i_int = i_width;
-    var_Set( p_vout, "snapshot-width", val );
+    var_Set( p_vout, "vout-snapshot-width", val );
     val.i_int = i_height;
-    var_Set( p_vout, "snapshot-height", val );
+    var_Set( p_vout, "vout-snapshot-height", val );
     val.i_int = i_datasize;
-    var_Set( p_vout, "snapshot-datasize", val );
+    var_Set( p_vout, "vout-snapshot-datasize", val );
 
     val.i_int = p_vout->p_sys->i_size;
-    var_Set( p_vout, "snapshot-cache-size", val );
+    var_Set( p_vout, "vout-snapshot-cache-size", val );
 
     val.p_address = p_vout->p_sys->p_list;
-    var_Set( p_vout, "snapshot-list-pointer", val );
+    var_Set( p_vout, "vout-snapshot-list-pointer", val );
 
     /* Get the p_input pointer (to access video times) */
     p_vout->p_sys->p_input = vlc_object_find( p_vout, VLC_OBJECT_INPUT,
@@ -299,20 +314,20 @@ static int Init( vout_thread_t *p_vout )
     if( !p_vout->p_sys->p_input )
         return VLC_ENOOBJ;
 
-    if( var_Create( p_vout->p_sys->p_input, "snapshot-id", VLC_VAR_INTEGER ) )
+    if( var_Create( p_vout->p_sys->p_input, "vout-snapshot-id", VLC_VAR_INTEGER ) )
     {
-        msg_Err( p_vout, "Cannot create snapshot-id variable in p_input (%d).",
-                 p_vout->p_sys->p_input->i_object_id );
+        msg_Err( p_vout, "Cannot create vout-snapshot-id variable in p_input(%p).",
+                 p_vout->p_sys->p_input );
         return VLC_EGENERIC;
     }
 
     /* Register the snapshot vout module at the input level */
-    val.i_int = p_vout->i_object_id;
+    val.p_address = p_vout;
 
-    if( var_Set( p_vout->p_sys->p_input, "snapshot-id", val ) )
+    if( var_Set( p_vout->p_sys->p_input, "vout-snapshot-id", val ) )
     {
-        msg_Err( p_vout, "Cannot register snapshot-id in p_input (%d).",
-                 p_vout->p_sys->p_input->i_object_id );
+        msg_Err( p_vout, "Cannot register vout-snapshot-id in p_input(%p).",
+                 p_vout->p_sys->p_input );
         return VLC_EGENERIC;
     }
 
@@ -337,12 +352,12 @@ static void Destroy( vlc_object_t *p_this )
     vout_thread_t *p_vout = ( vout_thread_t * )p_this;
     int i_index;
 
-    var_Destroy( p_vout->p_sys->p_input, "snapshot-id" );
+    var_Destroy( p_vout->p_sys->p_input, "vout-snapshot-id" );
 
     vlc_object_release( p_vout->p_sys->p_input );
-    var_Destroy( p_this, "snapshot-width" );
-    var_Destroy( p_this, "snapshot-height" );
-    var_Destroy( p_this, "snapshot-datasize" );
+    var_Destroy( p_this, "vout-snapshot-width" );
+    var_Destroy( p_this, "vout-snapshot-height" );
+    var_Destroy( p_this, "vout-snapshot-datasize" );
 
     for( i_index = 0 ; i_index < p_vout->p_sys->i_size ; i_index++ )
     {
@@ -356,19 +371,11 @@ static void Destroy( vlc_object_t *p_this )
 /* Return the position in ms from the start of the movie */
 static mtime_t snapshot_GetMovietime( vout_thread_t *p_vout )
 {
-    input_thread_t* p_input;
-    vlc_value_t val;
-    mtime_t i_result;
-
-    p_input = p_vout->p_sys->p_input;
+    input_thread_t *p_input = p_vout->p_sys->p_input;
     if( !p_input )
         return 0;
 
-    var_Get( p_input, "time", &val );
-
-    i_result = val.i_time - p_input->i_pts_delay;
-
-    return( i_result / 1000 );
+    return var_GetTime( p_input, "time" ) / 1000;
 }
 
 /*****************************************************************************
