@@ -2,7 +2,7 @@
  * custom_wave.c:
  *****************************************************************************
  * Copyright (C) 2004 the VideoLAN team
- * $Id: custom_wave.c 11664 2005-07-09 06:17:09Z courmisch $
+ * $Id: 8ccb9573cf57f865680be604959678b9e30c3183 $
  *
  * Authors: Cyril Deguet <asmax@videolan.org>
  *          code from projectM http://xmms-projectm.sourceforge.net
@@ -19,14 +19,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
-
-
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "common.h"
 #include "fatal.h"
@@ -63,14 +61,14 @@ extern int mesh_i;
 custom_wave_t * interface_wave = NULL;
 int interface_id = 0;
 extern preset_t * active_preset;
-inline void eval_custom_wave_init_conds(custom_wave_t * custom_wave);
+static inline void eval_custom_wave_init_conds(custom_wave_t * custom_wave);
 void load_unspec_init_cond(param_t * param);
 void destroy_per_point_eqn_tree(splaytree_t * tree);
 void destroy_param_db_tree(splaytree_t * tree);
 void destroy_per_frame_eqn_tree(splaytree_t * tree);
 void destroy_per_frame_init_eqn_tree(splaytree_t * tree);
 void destroy_init_cond_tree(splaytree_t * tree);
-inline void evalPerPointEqn(per_point_eqn_t * per_point_eqn);
+static inline void evalPerPointEqn(per_point_eqn_t * per_point_eqn);
 
 custom_wave_t * new_custom_wave(int id) {
 
@@ -606,18 +604,9 @@ custom_wave_t * find_custom_wave(int id, preset_t * preset, int create_flag) {
   return custom_wave;
 }
 
-inline void evalCustomWaveInitConditions() {
-  splay_traverse(eval_custom_wave_init_conds, active_preset->custom_wave_tree);
-}
-
-inline void eval_custom_wave_init_conds(custom_wave_t * custom_wave) {
-  splay_traverse(eval_init_cond, custom_wave->init_cond_tree);
-  splay_traverse(eval_init_cond, custom_wave->per_frame_init_eqn_tree);
-}
-
 /* Interface function. Makes another custom wave the current
    concern for per frame / point equations */
-inline custom_wave_t * nextCustomWave() {
+custom_wave_t * nextCustomWave() {
 
   if ((interface_wave = splay_find(&interface_id, active_preset->custom_wave_tree)) == NULL) {
     interface_id = 0;
@@ -632,7 +621,7 @@ inline custom_wave_t * nextCustomWave() {
 }
 
 
-inline void evalPerPointEqns() { 
+void evalPerPointEqns() { 
 
   int x;
 
@@ -658,7 +647,7 @@ inline void evalPerPointEqns() {
 }
 
 /* Evaluates a per point equation for the current custom wave given by interface_wave ptr */
-inline void evalPerPointEqn(per_point_eqn_t * per_point_eqn) {
+static inline void evalPerPointEqn(per_point_eqn_t * per_point_eqn) {
   
   
   int samples, size;
@@ -742,3 +731,7 @@ void load_unspec_init_cond(param_t * param) {
   }
  
 }
+
+void evalCustomWaveInitConditions() {
+  splay_traverse(eval_custom_wave_init_conds, active_preset->custom_wave_tree);
+}
