@@ -3,7 +3,7 @@
  * media_list.c).
  *****************************************************************************
  * Copyright (C) 2007 the VideoLAN team
- * $Id$
+ * $Id: 62818f8274c89b37848e43f52cdff28d70a282bf $
  *
  * Authors: Pierre d'Herbemont <pdherbemont # videolan.org>
  *
@@ -22,10 +22,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
-#include "libvlc_internal.h"
 #include <vlc/libvlc.h>
-#include <assert.h>
-#include "vlc_arrays.h"
+#include <vlc/libvlc_media.h>
+#include <vlc/libvlc_media_list.h>
+#include <vlc/libvlc_media_list_view.h>
+#include <vlc/libvlc_events.h>
+
+#include "libvlc_internal.h"  // Abuse, could and should be removed
+
+#include "media_internal.h"  // Abuse, could and should be removed
+#include "media_list_internal.h"  // Abuse, could and should be removed
+#include "media_list_view_internal.h"
 
 //#define DEBUG_FLAT_LIST
 
