@@ -2,7 +2,7 @@
  * var.c: object variables for input thread
  *****************************************************************************
  * Copyright (C) 2004-2007 the VideoLAN team
- * $Id: d3d1c0c47eb1b1405198639003cac489cc76f5ee $
+ * $Id: fcad8118d8ae7eade55d8418b008cf5a90e257fa $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -61,11 +61,19 @@ static int EsDelayCallback ( vlc_object_t *p_this, char const *psz_cmd,
 static int BookmarkCallback( vlc_object_t *p_this, char const *psz_cmd,
                              vlc_value_t oldval, vlc_value_t newval, void * );
 
+static int RecordCallback( vlc_object_t *p_this, char const *psz_cmd,
+                           vlc_value_t oldval, vlc_value_t newval,
+                           void *p_data );
+static int FrameNextCallback( vlc_object_t *p_this, char const *psz_cmd,
+                              vlc_value_t oldval, vlc_value_t newval,
+                              void *p_data );
+
 typedef struct
 {
     const char *psz_name;
     vlc_callback_t callback;
 } vlc_input_callback_t;
+
 static void InputAddCallbacks( input_thread_t *, const vlc_input_callback_t * );
 static void InputDelCallbacks( input_thread_t *, const vlc_input_callback_t * );
 
@@ -93,6 +101,8 @@ static const vlc_input_callback_t p_input_callbacks[] =
     CALLBACK( "video-es", ESCallback ),
     CALLBACK( "audio-es", ESCallback ),
     CALLBACK( "spu-es", ESCallback ),
+    CALLBACK( "record", RecordCallback ),
+    CALLBACK( "frame-next", FrameNextCallback ),
 
     CALLBACK( NULL, NULL )
 };
@@ -122,7 +132,7 @@ void input_ControlVarInit ( input_thread_t *p_input )
 
     /* State */
     var_Create( p_input, "state", VLC_VAR_INTEGER );
-    val.i_int = p_input->i_state;
+    val.i_int = p_input->p->i_state;
     var_Change( p_input, "state", VLC_VAR_SETVALUE, &val, NULL );
 
     /* Rate */
@@ -134,6 +144,8 @@ void input_ControlVarInit ( input_thread_t *p_input )
 
     var_Create( p_input, "rate-faster", VLC_VAR_VOID );
 
+    var_Create( p_input, "frame-next", VLC_VAR_VOID );
+
     /* Position */
     var_Create( p_input, "position",  VLC_VAR_FLOAT );
     var_Create( p_input, "position-offset",  VLC_VAR_FLOAT );
@@ -183,15 +195,12 @@ void input_ControlVarInit ( input_thread_t *p_input )
 
     /* Delay */
     var_Create( p_input, "audio-delay", VLC_VAR_TIME );
-    val.i_time = 0;
+    val.i_time = INT64_C(1000) * var_GetInteger( p_input, "audio-desync" );
     var_Change( p_input, "audio-delay", VLC_VAR_SETVALUE, &val, NULL );
     var_Create( p_input, "spu-delay", VLC_VAR_TIME );
     val.i_time = 0;
     var_Change( p_input, "spu-delay", VLC_VAR_SETVALUE, &val, NULL );
 
-    p_input->p->pts_adjust.auto_adjust = var_CreateGetBool(
-            p_input, "auto-adjust-pts-delay" );
-
     /* Video ES */
     var_Create( p_input, "video-es", VLC_VAR_INTEGER | VLC_VAR_HASCHOICE );
     text.psz_string = _("Video Track");
@@ -216,19 +225,8 @@ void input_ControlVarInit ( input_thread_t *p_input )
 
     if( !p_input->b_preparsing )
     {
-        /* Special "intf-change" variable, it allows intf to set up a callback
-         * to be notified of some changes.
-         *
-         * Add rate-change to inform about rate changin
-         *
-         * TODO list all changes warn by this callbacks */
-        var_Create( p_input, "intf-change", VLC_VAR_BOOL );
-        var_SetBool( p_input, "intf-change", true );
-        var_Create( p_input, "rate-change", VLC_VAR_BOOL );
-        var_SetBool( p_input, "rate-change", true );
-
-        var_Create( p_input, "intf-change-vout", VLC_VAR_BOOL );
-        var_SetBool( p_input, "intf-change-vout", true );
+        /* Special "intf-event" variable. */
+        var_Create( p_input, "intf-event", VLC_VAR_INTEGER );
     }
 
     /* Add all callbacks
@@ -407,8 +405,6 @@ void input_ControlVarTitle( input_thread_t *p_input, int i_title )
  *****************************************************************************/
 void input_ConfigVarInit ( input_thread_t *p_input )
 {
-    vlc_value_t val;
-
     /* Create Object Variables for private use only */
 
     if( !p_input->b_preparsing )
@@ -447,16 +443,14 @@ void input_ConfigVarInit ( input_thread_t *p_input )
 
         var_Create( p_input, "input-repeat",
                     VLC_VAR_INTEGER|VLC_VAR_DOINHERIT );
-        var_Create( p_input, "start-time", VLC_VAR_INTEGER|VLC_VAR_DOINHERIT );
-        var_Create( p_input, "stop-time", VLC_VAR_INTEGER|VLC_VAR_DOINHERIT );
-        var_Create( p_input, "run-time", VLC_VAR_INTEGER|VLC_VAR_DOINHERIT );
+        var_Create( p_input, "start-time", VLC_VAR_FLOAT|VLC_VAR_DOINHERIT );
+        var_Create( p_input, "stop-time", VLC_VAR_FLOAT|VLC_VAR_DOINHERIT );
+        var_Create( p_input, "run-time", VLC_VAR_FLOAT|VLC_VAR_DOINHERIT );
+        var_Create( p_input, "input-fast-seek", VLC_VAR_BOOL|VLC_VAR_DOINHERIT );
 
         var_Create( p_input, "input-slave",
                     VLC_VAR_STRING | VLC_VAR_DOINHERIT );
 
-        var_Create( p_input, "minimize-threads",
-                    VLC_VAR_BOOL|VLC_VAR_DOINHERIT );
-
         var_Create( p_input, "audio-desync",
                     VLC_VAR_INTEGER | VLC_VAR_DOINHERIT );
         var_Create( p_input, "cr-average",
@@ -465,19 +459,46 @@ void input_ConfigVarInit ( input_thread_t *p_input )
                     VLC_VAR_INTEGER | VLC_VAR_DOINHERIT);
     }
 
-    var_Create( p_input, "seekable", VLC_VAR_BOOL );
-    val.b_bool = true; /* Fixed later*/
-    var_Change( p_input, "seekable", VLC_VAR_SETVALUE, &val, NULL );
+    var_Create( p_input, "can-seek", VLC_VAR_BOOL );
+    var_SetBool( p_input, "can-seek", true ); /* Fixed later*/
+
     var_Create( p_input, "can-pause", VLC_VAR_BOOL );
-    val.b_bool = true; /* Fixed later*/
-    var_Change( p_input, "can-pause", VLC_VAR_SETVALUE, &val, NULL );
+    var_SetBool( p_input, "can-pause", true ); /* Fixed later*/
+
+    var_Create( p_input, "can-rate", VLC_VAR_BOOL );
+    var_SetBool( p_input, "can-rate", false );
+
+    var_Create( p_input, "can-rewind", VLC_VAR_BOOL );
+    var_SetBool( p_input, "can-rewind", false );
+
+    var_Create( p_input, "can-record", VLC_VAR_BOOL );
+    var_SetBool( p_input, "can-record", false ); /* Fixed later*/
+
+    var_Create( p_input, "record", VLC_VAR_BOOL );
+    var_SetBool( p_input, "record", false );
+
     var_Create( p_input, "teletext-es", VLC_VAR_INTEGER );
     var_SetInteger( p_input, "teletext-es", -1 );
 
+    var_Create( p_input, "signal-quality", VLC_VAR_FLOAT );
+    var_SetFloat( p_input, "signal-quality", -1 );
+
+    var_Create( p_input, "signal-strength", VLC_VAR_FLOAT );
+    var_SetFloat( p_input, "signal-strength", -1 );
+
+    var_Create( p_input, "program-scrambled", VLC_VAR_BOOL );
+    var_SetBool( p_input, "program-scrambled", false );
+
+    var_Create( p_input, "cache", VLC_VAR_FLOAT );
+    var_SetFloat( p_input, "cache", 0.0 );
+
+    /* */
+    var_Create( p_input, "input-record-native", VLC_VAR_BOOL | VLC_VAR_DOINHERIT );
+
     /* */
-    var_Create( p_input, "access-filter", VLC_VAR_STRING | VLC_VAR_DOINHERIT );
     var_Create( p_input, "access", VLC_VAR_STRING | VLC_VAR_DOINHERIT );
     var_Create( p_input, "demux", VLC_VAR_STRING | VLC_VAR_DOINHERIT );
+    var_Create( p_input, "stream-filter", VLC_VAR_STRING | VLC_VAR_DOINHERIT );
 
     /* Meta */
     var_Create( p_input, "meta-title", VLC_VAR_STRING | VLC_VAR_DOINHERIT );
@@ -502,6 +523,7 @@ static void InputAddCallbacks( input_thread_t *p_input,
                          p_callbacks[i].psz_name,
                          p_callbacks[i].callback, NULL );
 }
+
 static void InputDelCallbacks( input_thread_t *p_input,
                                const vlc_input_callback_t *p_callbacks )
 {
@@ -511,6 +533,7 @@ static void InputDelCallbacks( input_thread_t *p_input,
                          p_callbacks[i].psz_name,
                          p_callbacks[i].callback, NULL );
 }
+
 /*****************************************************************************
  * All Callbacks:
  *****************************************************************************/
@@ -549,7 +572,6 @@ static int RateCallback( vlc_object_t *p_this, char const *psz_cmd,
     {
         input_ControlPush( p_input, INPUT_CONTROL_SET_RATE, &newval );
     }
-
     return VLC_SUCCESS;
 }
 
@@ -558,32 +580,32 @@ static int PositionCallback( vlc_object_t *p_this, char const *psz_cmd,
                              void *p_data )
 {
     input_thread_t *p_input = (input_thread_t*)p_this;
-    vlc_value_t val, length;
     VLC_UNUSED(oldval); VLC_UNUSED(p_data);
 
     if( !strcmp( psz_cmd, "position-offset" ) )
     {
-        input_ControlPush( p_input, INPUT_CONTROL_SET_POSITION_OFFSET, &newval );
-
-        val.f_float = var_GetFloat( p_input, "position" ) + newval.f_float;
-        if( val.f_float < 0.0 ) val.f_float = 0.0;
-        if( val.f_float > 1.0 ) val.f_float = 1.0;
-        var_Change( p_input, "position", VLC_VAR_SETVALUE, &val, NULL );
+        float f_position = var_GetFloat( p_input, "position" ) + newval.f_float;
+        if( f_position < 0.0 )
+            f_position = 0.0;
+        else if( f_position > 1.0 )
+            f_position = 1.0;
+        var_SetFloat( p_this, "position", f_position );
     }
     else
     {
-        val.f_float = newval.f_float;
+        /* Update "length" for better intf behavour */
+        const mtime_t i_length = var_GetTime( p_input, "length" );
+        if( i_length > 0 && newval.f_float >= 0.0 && newval.f_float <= 1.0 )
+        {
+            vlc_value_t val;
+
+            val.i_time = i_length * newval.f_float;
+            var_Change( p_input, "time", VLC_VAR_SETVALUE, &val, NULL );
+        }
+
+        /* */
         input_ControlPush( p_input, INPUT_CONTROL_SET_POSITION, &newval );
     }
-
-    /* Update "position" for better intf behavour */
-    var_Get( p_input, "length", &length );
-    if( length.i_time > 0 && val.f_float >= 0.0 && val.f_float <= 1.0 )
-    {
-        val.i_time = length.i_time * val.f_float;
-        var_Change( p_input, "time", VLC_VAR_SETVALUE, &val, NULL );
-    }
-
     return VLC_SUCCESS;
 }
 
@@ -591,31 +613,30 @@ static int TimeCallback( vlc_object_t *p_this, char const *psz_cmd,
                          vlc_value_t oldval, vlc_value_t newval, void *p_data )
 {
     input_thread_t *p_input = (input_thread_t*)p_this;
-    vlc_value_t val, length;
     VLC_UNUSED(oldval); VLC_UNUSED(p_data);
 
     if( !strcmp( psz_cmd, "time-offset" ) )
     {
-        input_ControlPush( p_input, INPUT_CONTROL_SET_TIME_OFFSET, &newval );
-        val.i_time = var_GetTime( p_input, "time" ) + newval.i_time;
-        if( val.i_time < 0 ) val.i_time = 0;
-        /* TODO maybe test against i_length ? */
-        var_Change( p_input, "time", VLC_VAR_SETVALUE, &val, NULL );
+        mtime_t i_time = var_GetTime( p_input, "time" ) + newval.i_time;
+        if( i_time < 0 )
+            i_time = 0;
+        var_SetTime( p_this, "time", i_time );
     }
     else
     {
-        val.i_time = newval.i_time;
+        /* Update "position" for better intf behavour */
+        const mtime_t i_length = var_GetTime( p_input, "length" );
+        if( i_length > 0 && newval.i_time >= 0 && newval.i_time <= i_length )
+        {
+            vlc_value_t val;
+
+            val.f_float = (double)newval.i_time/(double)i_length;
+            var_Change( p_input, "position", VLC_VAR_SETVALUE, &val, NULL );
+        }
+
+        /* */
         input_ControlPush( p_input, INPUT_CONTROL_SET_TIME, &newval );
     }
-
-    /* Update "position" for better intf behavour */
-    var_Get( p_input, "length", &length );
-    if( length.i_time > 0 && val.i_time >= 0 && val.i_time <= length.i_time )
-    {
-        val.f_float = (double)val.i_time/(double)length.i_time;
-        var_Change( p_input, "position", VLC_VAR_SETVALUE, &val, NULL );
-    }
-
     return VLC_SUCCESS;
 }
 
@@ -692,6 +713,16 @@ static int SeekpointCallback( vlc_object_t *p_this, char const *psz_cmd,
     else
     {
         input_ControlPush( p_input, INPUT_CONTROL_SET_SEEKPOINT, &newval );
+        val.i_int = newval.i_int;
+    }
+
+    /* Actualize "title %2i" variable */
+    if( val.i_int >= 0 && val.i_int < count.i_int )
+    {
+        int i_title = var_GetInteger( p_input, "title" );
+        char psz_titlevar[10] = {0};
+        snprintf( psz_titlevar, 10, "title %2i", i_title );
+        var_Change( p_input, psz_titlevar, VLC_VAR_SETVALUE, &val, NULL );
     }
 
     return VLC_SUCCESS;
@@ -756,15 +787,12 @@ static int EsDelayCallback ( vlc_object_t *p_this, char const *psz_cmd,
 
     if( !strcmp( psz_cmd, "audio-delay" ) )
     {
-        /*Change i_pts_delay to make sure es are decoded in time*/
-        if (newval.i_int < 0 || oldval.i_int < 0 )
-        {
-            p_input->i_pts_delay -= newval.i_int - oldval.i_int;
-        }
         input_ControlPush( p_input, INPUT_CONTROL_SET_AUDIO_DELAY, &newval );
     }
     else if( !strcmp( psz_cmd, "spu-delay" ) )
+    {
         input_ControlPush( p_input, INPUT_CONTROL_SET_SPU_DELAY, &newval );
+    }
     return VLC_SUCCESS;
 }
 
@@ -779,3 +807,29 @@ static int BookmarkCallback( vlc_object_t *p_this, char const *psz_cmd,
 
     return VLC_SUCCESS;
 }
+
+static int RecordCallback( vlc_object_t *p_this, char const *psz_cmd,
+                           vlc_value_t oldval, vlc_value_t newval,
+                           void *p_data )
+{
+    input_thread_t *p_input = (input_thread_t*)p_this;
+    VLC_UNUSED(psz_cmd); VLC_UNUSED(oldval); VLC_UNUSED(p_data);
+
+    input_ControlPush( p_input, INPUT_CONTROL_SET_RECORD_STATE, &newval );
+
+    return VLC_SUCCESS;
+}
+
+static int FrameNextCallback( vlc_object_t *p_this, char const *psz_cmd,
+                              vlc_value_t oldval, vlc_value_t newval,
+                              void *p_data )
+{
+    input_thread_t *p_input = (input_thread_t*)p_this;
+    VLC_UNUSED(psz_cmd); VLC_UNUSED(oldval); VLC_UNUSED(p_data);
+    VLC_UNUSED(newval);
+
+    input_ControlPush( p_input, INPUT_CONTROL_SET_FRAME_NEXT, NULL );
+
+    return VLC_SUCCESS;
+}
+
