@@ -2,7 +2,7 @@
  * loadsave.c : Playlist loading / saving functions
  *****************************************************************************
  * Copyright (C) 1999-2004 the VideoLAN team
- * $Id: 3bb3b2abee92f8065db92c1285308266b4a10aca $
+ * $Id: 34378730761e03e6e9bf0046f938d27a3f89b2df $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -30,6 +30,7 @@
 #include "playlist_internal.h"
 #include "config/configuration.h"
 #include <vlc_charset.h>
+#include <vlc_url.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -40,7 +41,7 @@ int playlist_Export( playlist_t * p_playlist, const char *psz_filename ,
                      playlist_item_t *p_export_root,const char *psz_type )
 {
     module_t *p_module;
-    playlist_export_t *p_export;
+    playlist_export_t export;
 
     if( p_export_root == NULL ) return VLC_EGENERIC;
 
@@ -48,48 +49,53 @@ int playlist_Export( playlist_t * p_playlist, const char *psz_filename ,
                     p_export_root->p_input->psz_name, psz_filename );
 
     /* Prepare the playlist_export_t structure */
-    p_export = (playlist_export_t *)malloc( sizeof(playlist_export_t) );
-    if( !p_export)
-        return VLC_ENOMEM;
-    p_export->psz_filename = psz_filename ? strdup( psz_filename ) : NULL;
-    p_export->p_file = utf8_fopen( psz_filename, "wt" );
-    if( !p_export->p_file )
+    export.psz_filename = psz_filename ? strdup( psz_filename ) : NULL;
+    export.p_file = utf8_fopen( psz_filename, "wt" );
+    if( export.p_file == NULL )
     {
         msg_Err( p_playlist , "could not create playlist file %s (%m)",
                  psz_filename );
-        free( p_export->psz_filename );
-        free( p_export );
+        free( export.psz_filename );
         return VLC_EGENERIC;
     }
 
-    p_export->p_root = p_export_root;
+    export.p_root = p_export_root;
 
-    /* Lock the playlist */
-    vlc_object_lock( p_playlist );
-    p_playlist->p_private = (void *)p_export;
+    playlist_Lock( p_playlist );
+    p_playlist->p_private = (void *)&export;
 
     /* And call the module ! All work is done now */
-    int i_ret;
-    p_module = module_Need( p_playlist, "playlist export", psz_type, true);
+    p_module = module_need( p_playlist, "playlist export", psz_type, true);
     if( !p_module )
-    {
         msg_Warn( p_playlist, "exporting playlist failed" );
-        i_ret = VLC_ENOOBJ;
-    }
     else
-    {
-        module_Unneed( p_playlist , p_module );
-        i_ret = VLC_SUCCESS;
-    }
+        module_unneed( p_playlist , p_module );
+    p_playlist->p_private = NULL;
+    playlist_Unlock( p_playlist );
 
     /* Clean up */
-    fclose( p_export->p_file );
-    free( p_export->psz_filename );
-    free( p_export );
-    p_playlist->p_private = NULL;
-    vlc_object_unlock( p_playlist );
+    fclose( export.p_file );
+    free( export.psz_filename );
 
-    return i_ret;
+    return p_module ? VLC_SUCCESS : VLC_ENOOBJ;
+}
+
+int playlist_Import( playlist_t *p_playlist, const char *psz_file )
+{
+    input_item_t *p_input;
+    const char *const psz_option = "meta-file";
+    char *psz_uri = make_URI( psz_file );
+
+    if( psz_uri == NULL )
+        return VLC_EGENERIC;
+
+    p_input = input_item_NewExt( p_playlist, psz_uri, psz_file,
+                                 1, &psz_option, VLC_INPUT_OPTION_TRUSTED, -1 );
+    free( psz_uri );
+
+    playlist_AddInput( p_playlist, p_input, PLAYLIST_APPEND, PLAYLIST_END,
+                       true, false );
+    return input_Read( p_playlist, p_input, true );
 }
 
 /*****************************************************************************
@@ -109,45 +115,55 @@ static void input_item_subitem_added( const vlc_event_t * p_event,
 
 int playlist_MLLoad( playlist_t *p_playlist )
 {
-    char *psz_datadir = config_GetUserDataDir();
+    char *psz_datadir;
     char *psz_uri = NULL;
     input_item_t *p_input;
 
-    if( !config_GetInt( p_playlist, "media-library") ) return VLC_SUCCESS;
+    if( !config_GetInt( p_playlist, "media-library") )
+        return VLC_SUCCESS;
+
+    psz_datadir = config_GetUserDataDir();
+
     if( !psz_datadir ) /* XXX: This should never happen */
     {
         msg_Err( p_playlist, "no data directory, cannot load media library") ;
         return VLC_EGENERIC;
     }
 
-    if( asprintf( &psz_uri, "%s" DIR_SEP "ml.xspf", psz_datadir ) == -1 )
-    {
-        psz_uri = NULL;
-        goto error;
+    if( asprintf( &psz_uri, "%s" DIR_SEP "ml.xspf", psz_datadir ) != -1 )
+    {   /* loosy check for media library file */
+        struct stat st;
+        int ret = utf8_stat( psz_uri , &st );
+        free( psz_uri );
+        if( ret )
+        {
+            free( psz_datadir );
+            return VLC_EGENERIC;
+        }
     }
-    struct stat p_stat;
-    /* checks if media library file is present */
-    if( utf8_stat( psz_uri , &p_stat ) )
-        goto error;
-    free( psz_uri );
 
-    /* FIXME: WTF? stat() should never be used right before open()! */
-    if( asprintf( &psz_uri, "file/xspf-open://%s" DIR_SEP "ml.xspf",
-                  psz_datadir ) == -1 )
-    {
+    psz_uri = make_URI( psz_datadir );
+    free( psz_datadir );
+    psz_datadir = psz_uri;
+    if( psz_datadir == NULL )
+        return VLC_EGENERIC;
+
+    /* Force XSPF demux (psz_datadir was a path, now it is a file URI) */
+    if( asprintf( &psz_uri, "file/xspf-open%s/ml.xspf", psz_datadir+4 ) == -1 )
         psz_uri = NULL;
-        goto error;
-    }
     free( psz_datadir );
     psz_datadir = NULL;
+    if( psz_uri == NULL )
+        return VLC_ENOMEM;
 
-    const char *const psz_option = "meta-file";
+    const char *const options[1] = { "meta-file", };
     /* that option has to be cleaned in input_item_subitem_added() */
     /* vlc_gc_decref() in the same function */
-    p_input = input_item_NewExt( p_playlist, psz_uri,
-                                _("Media Library"), 1, &psz_option, -1 );
+    p_input = input_item_NewExt( p_playlist, psz_uri, _("Media Library"),
+                                 1, options, VLC_INPUT_OPTION_TRUSTED, -1 );
+    free( psz_uri );
     if( p_input == NULL )
-        goto error;
+        return VLC_EGENERIC;
 
     PL_LOCK;
     if( p_playlist->p_ml_onelevel->p_input )
@@ -164,7 +180,7 @@ int playlist_MLLoad( playlist_t *p_playlist )
     vlc_event_attach( &p_input->event_manager, vlc_InputItemSubItemAdded,
                         input_item_subitem_added, p_playlist );
 
-    p_playlist->b_doing_ml = true;
+    pl_priv(p_playlist)->b_doing_ml = true;
     PL_UNLOCK;
 
     stats_TimerStart( p_playlist, "ML Load", STATS_TIMER_ML_LOAD );
@@ -172,26 +188,25 @@ int playlist_MLLoad( playlist_t *p_playlist )
     stats_TimerStop( p_playlist,STATS_TIMER_ML_LOAD );
 
     PL_LOCK;
-    p_playlist->b_doing_ml = false;
+    pl_priv(p_playlist)->b_doing_ml = false;
     PL_UNLOCK;
 
     vlc_event_detach( &p_input->event_manager, vlc_InputItemSubItemAdded,
                         input_item_subitem_added, p_playlist );
 
     vlc_gc_decref( p_input );
-    free( psz_uri );
     return VLC_SUCCESS;
-
-error:
-    free( psz_uri );
-    free( psz_datadir );
-    return VLC_ENOMEM;
 }
 
 int playlist_MLDump( playlist_t *p_playlist )
 {
-    char *psz_datadir = config_GetUserDataDir();
-    if( !config_GetInt( p_playlist, "media-library") ) return VLC_SUCCESS;
+    char *psz_datadir;
+
+    if( !config_GetInt( p_playlist, "media-library") )
+        return VLC_SUCCESS;
+
+    psz_datadir = config_GetUserDataDir();
+
     if( !psz_datadir ) /* XXX: This should never happen */
     {
         msg_Err( p_playlist, "no data directory, cannot save media library") ;
